@@ -22,9 +22,9 @@ use crate::{
     parse::{is_number, parse_bool, parse_duration, parse_hex, parse_u16},
     parse_items::{Map, MapItem},
 };
-use anyhow::{self as ah, format_err as err, Context as _};
-use letmein_proto::{Key, ResourceId, UserId, PORT};
-use sha3::{Digest, Sha3_256};
+use anyhow::{self as ah, Context as _, format_err as err};
+use letmein_proto::{Key, PORT, ResourceId, UserId};
+use sha3::{Digest as _, Sha3_256};
 use std::{
     collections::HashMap,
     path::{Path, PathBuf},
@@ -60,6 +60,7 @@ impl ConfigChecksum {
     pub const SIZE: usize = 32;
 
     /// Calculate the checksum from a raw byte stream.
+    #[must_use]
     pub fn calculate(content: &[u8]) -> Self {
         let mut hash = Sha3_256::new();
         hash.update((content.len() as u64).to_be_bytes());
@@ -69,6 +70,7 @@ impl ConfigChecksum {
     }
 
     /// Get the calculated checksum digest.
+    #[must_use]
     pub fn as_bytes(&self) -> &[u8; ConfigChecksum::SIZE] {
         &self.0
     }
@@ -150,17 +152,17 @@ pub enum Resource {
 }
 
 impl Resource {
+    #[must_use]
     pub fn id(&self) -> ResourceId {
         match self {
-            Self::Port { id, .. } => *id,
-            Self::Jump { id, .. } => *id,
+            Self::Port { id, .. } | Self::Jump { id, .. } => *id,
         }
     }
 
+    #[must_use]
     pub fn contains_user(&self, id: UserId) -> bool {
         let users = match self {
-            Self::Port { users, .. } => users,
-            Self::Jump { users, .. } => users,
+            Self::Port { users, .. } | Self::Jump { users, .. } => users,
         };
         if users.is_empty() {
             // This resource is unrestricted.
@@ -170,10 +172,10 @@ impl Resource {
         }
     }
 
+    #[must_use]
     pub fn timeout(&self) -> Option<Duration> {
         match self {
-            Self::Port { timeout, .. } => *timeout,
-            Self::Jump { timeout, .. } => *timeout,
+            Self::Port { timeout, .. } | Self::Jump { timeout, .. } => *timeout,
         }
     }
 }
@@ -199,7 +201,7 @@ impl std::fmt::Display for Resource {
 
         fn write_timeout(
             f: &mut std::fmt::Formatter<'_>,
-            timeout: &Option<Duration>,
+            timeout: Option<&Duration>,
         ) -> Result<(), std::fmt::Error> {
             if let Some(timeout) = timeout {
                 writeln!(f, "  timeout: {} s", timeout.as_secs())?;
@@ -209,7 +211,7 @@ impl std::fmt::Display for Resource {
 
         fn write_chain(
             f: &mut std::fmt::Formatter<'_>,
-            chain: &Option<String>,
+            chain: Option<&str>,
             match_saddr: bool,
             name: &str,
         ) -> Result<(), std::fmt::Error> {
@@ -241,7 +243,7 @@ impl std::fmt::Display for Resource {
                 writeln!(f, "Port resource:")?;
                 writeln!(f, "  id: {id}")?;
                 writeln!(f, "  port: {port} {tcpudp}")?;
-                write_timeout(f, timeout)?;
+                write_timeout(f, timeout.as_ref())?;
                 write_users(f, users)?;
             }
             Self::Jump {
@@ -257,10 +259,10 @@ impl std::fmt::Display for Resource {
             } => {
                 writeln!(f, "Jump resource:")?;
                 writeln!(f, "  id: {id}")?;
-                write_chain(f, input, *input_match_saddr, "input")?;
-                write_chain(f, forward, *forward_match_saddr, "forward")?;
-                write_chain(f, output, *output_match_saddr, "output")?;
-                write_timeout(f, timeout)?;
+                write_chain(f, input.as_deref(), *input_match_saddr, "input")?;
+                write_chain(f, forward.as_deref(), *forward_match_saddr, "forward")?;
+                write_chain(f, output.as_deref(), *output_match_saddr, "output")?;
+                write_timeout(f, timeout.as_ref())?;
                 write_users(f, users)?;
             }
         }
@@ -489,7 +491,7 @@ fn extract_resource_port(
                     if !users.is_empty() {
                         return Err(err!("[RESOURCE] multiple 'users' values"));
                     }
-                    users = vs.clone();
+                    users.clone_from(vs);
                 } else {
                     return Err(err!("[RESOURCE] unknown option: {k}"));
                 }
@@ -616,7 +618,7 @@ fn extract_resource_jump(
                     if !users.is_empty() {
                         return Err(err!("[RESOURCE] multiple 'users' values"));
                     }
-                    users = vs.clone();
+                    users.clone_from(vs);
                 } else {
                     return Err(err!("[RESOURCE] unknown option: {k}"));
                 }
@@ -690,7 +692,7 @@ fn get_resources(ini: &Ini) -> ah::Result<HashMap<ResourceId, Resource>> {
                 return Err(err!(
                     "[RESOURCE] Resource ID '{id}' is not a 'port' resource."
                 ));
-            };
+            }
         }
     }
     Ok(resources)
@@ -703,6 +705,7 @@ fn get_default_user(ini: &Ini) -> ah::Result<UserId> {
     Ok(Default::default())
 }
 
+#[allow(clippy::unnecessary_wraps)]
 fn get_nft_exe(ini: &Ini) -> ah::Result<PathBuf> {
     if let Some(nft_exe) = ini.get("NFTABLES", "exe") {
         return Ok(nft_exe.trim().into());
@@ -721,15 +724,16 @@ fn get_nft_family(ini: &Ini) -> ah::Result<String> {
         }
         .to_string())
     } else {
-        Ok("".to_string())
+        Ok(String::new())
     }
 }
 
+#[allow(clippy::unnecessary_wraps)]
 fn get_nft_table(ini: &Ini) -> ah::Result<String> {
     if let Some(nft_table) = ini.get("NFTABLES", "table") {
         Ok(nft_table.trim().to_string())
     } else {
-        Ok("".to_string())
+        Ok(String::new())
     }
 }
 
@@ -749,7 +753,7 @@ fn get_nft_chain(ini: &Ini, field: &str) -> ah::Result<String> {
             Ok(chain)
         }
     } else {
-        Ok("".to_string())
+        Ok(String::new())
     }
 }
 
@@ -783,7 +787,7 @@ pub enum ConfigVariant {
     Client,
 }
 
-/// Parsed letmein.conf or letmeind.conf. (See [ConfigVariant]).
+/// Parsed letmein.conf or letmeind.conf. (See [`ConfigVariant`]).
 #[derive(Clone, Default, Debug)]
 pub struct Config {
     checksum: ConfigChecksum,
@@ -808,6 +812,7 @@ pub struct Config {
 
 impl Config {
     /// Create a new configuration instance with all-default values.
+    #[must_use]
     pub fn new(variant: ConfigVariant) -> Self {
         Self {
             checksum: Default::default(),
@@ -819,6 +824,8 @@ impl Config {
     }
 
     /// Get the default configuration file path.
+    #[must_use]
+    #[allow(clippy::single_match_else)]
     pub fn get_default_path(variant: ConfigVariant) -> PathBuf {
         // The build-time environment variable LETMEIN_CONF_PREFIX can be
         // used to give an additional prefix.
@@ -847,6 +854,7 @@ impl Config {
     }
 
     /// Get the actual path the configuration was read from.
+    #[must_use]
     pub fn get_path(&self) -> Option<&Path> {
         self.path.as_deref()
     }
@@ -856,7 +864,7 @@ impl Config {
         if let Ok(ini) = Ini::new_from_file(path) {
             self.load_ini(&ini)?;
         } else if self.variant == ConfigVariant::Server {
-            return Err(err!("Failed to load configuration {path:?}"));
+            return Err(err!("Failed to load configuration {}", path.display()));
         }
         self.path = Some(path.to_path_buf());
         Ok(())
@@ -913,60 +921,71 @@ impl Config {
     }
 
     /// Calculate a checksum that represents the content.
+    #[must_use]
     pub fn checksum(&self) -> &ConfigChecksum {
         &self.checksum
     }
 
     /// Get the `debug` option from `[GENERAL]` section.
+    #[must_use]
     pub fn debug(&self) -> bool {
         self.debug
     }
 
     /// Get the `port` option from `[GENERAL]` section.
+    #[must_use]
     pub fn port(&self) -> ControlPort {
         self.port
     }
 
     /// Get the `control-timeout` option from `[GENERAL]` section.
+    #[must_use]
     pub fn control_timeout(&self) -> Duration {
         self.control_timeout
     }
 
     /// Get the `control-error-policy` option from `[GENERAL]` section.
+    #[must_use]
     pub fn control_error_policy(&self) -> ErrorPolicy {
         self.control_error_policy
     }
 
     /// Get the `seccomp` option from `[GENERAL]` section.
+    #[must_use]
     pub fn seccomp(&self) -> Seccomp {
         self.seccomp
     }
 
     /// Get a list of all configured users.
+    #[must_use]
     pub fn users(&self) -> Vec<UserId> {
-        let mut users: Vec<UserId> = self.keys.keys().cloned().collect();
+        let mut users: Vec<UserId> = self.keys.keys().copied().collect();
         users.sort();
         users
     }
 
     /// Get a key value by key identifier from the `[KEYS]` section.
+    #[must_use]
     pub fn key(&self, id: UserId) -> Option<&Key> {
         self.keys.get(&id)
     }
 
     /// Get a list of all configured resources.
+    #[must_use]
     pub fn resources(&self) -> Vec<Resource> {
         let mut resources: Vec<Resource> = self.resources.values().cloned().collect();
-        resources.sort_by_key(|r| r.id());
+        resources.sort_by_key(Resource::id);
         resources
     }
 
     /// Get a resource value by resource identifier from the `[RESOURCES]` section.
+    #[must_use]
     pub fn resource(&self, id: ResourceId) -> Option<&Resource> {
         self.resources.get(&id)
     }
 
     /// Lookup a resource id by a port number in the `[RESOURCES]` section.
+    #[must_use]
     pub fn resource_id_by_port(&self, port: u16, user_id: Option<UserId>) -> Option<ResourceId> {
         for (k, v) in &self.resources {
             match v {
@@ -988,41 +1007,49 @@ impl Config {
     }
 
     /// Get the `default-user` option from `[CLIENT]` section.
+    #[must_use]
     pub fn default_user(&self) -> UserId {
         self.default_user
     }
 
     /// Get the `exe` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_exe(&self) -> &Path {
         &self.nft_exe
     }
 
     /// Get the `family` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_family(&self) -> &str {
         &self.nft_family
     }
 
     /// Get the `table` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_table(&self) -> &str {
         &self.nft_table
     }
 
     /// Get the `chain-input` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_chain_input(&self) -> &str {
         &self.nft_chain_input
     }
 
     /// Get the `chain-forward` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_chain_forward(&self) -> &str {
         &self.nft_chain_forward
     }
 
     /// Get the `chain-output` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_chain_output(&self) -> &str {
         &self.nft_chain_output
     }
 
     /// Get the `timeout` option from `[NFTABLES]` section.
+    #[must_use]
     pub fn nft_timeout(&self) -> Duration {
         self.nft_timeout
     }
@@ -1127,7 +1154,7 @@ mod tests {
         .unwrap();
         let keys = get_keys(&ini).unwrap();
         assert_eq!(
-            keys.get(&0xABCD1234.into()).unwrap(),
+            keys.get(&0xABCD_1234.into()).unwrap(),
             &[
                 0x99, 0x88, 0x77, 0x66, 0x55, 0x44, 0x33, 0x22, 0x11, 0x00, 0x99, 0x88, 0x77, 0x66,
                 0x55, 0x44, 0x33, 0x22, 0x11, 0x00, 0x99, 0x88, 0x77, 0x66, 0x55, 0x44, 0x33, 0x22,
@@ -1143,9 +1170,9 @@ mod tests {
             .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x9876ABCD.into()).unwrap(),
+            resources.get(&0x9876_ABCD.into()).unwrap(),
             &Resource::Port {
-                id: 0x9876ABCD.into(),
+                id: 0x9876_ABCD.into(),
                 port: 4096,
                 tcp: true,
                 udp: false,
@@ -1159,9 +1186,9 @@ mod tests {
             .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x9876ABCD.into()).unwrap(),
+            resources.get(&0x9876_ABCD.into()).unwrap(),
             &Resource::Port {
-                id: 0x9876ABCD.into(),
+                id: 0x9876_ABCD.into(),
                 port: 4096,
                 tcp: true,
                 udp: false,
@@ -1175,9 +1202,9 @@ mod tests {
             .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x9876ABCD.into()).unwrap(),
+            resources.get(&0x9876_ABCD.into()).unwrap(),
             &Resource::Port {
-                id: 0x9876ABCD.into(),
+                id: 0x9876_ABCD.into(),
                 port: 4096,
                 tcp: false,
                 udp: true,
@@ -1191,9 +1218,9 @@ mod tests {
             .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x9876ABCD.into()).unwrap(),
+            resources.get(&0x9876_ABCD.into()).unwrap(),
             &Resource::Port {
-                id: 0x9876ABCD.into(),
+                id: 0x9876_ABCD.into(),
                 port: 4096,
                 tcp: true,
                 udp: true,
@@ -1210,9 +1237,9 @@ mod tests {
             .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x1234FEDC.into()).unwrap(),
+            resources.get(&0x1234_FEDC.into()).unwrap(),
             &Resource::Jump {
-                id: 0x1234FEDC.into(),
+                id: 0x1234_FEDC.into(),
                 input: Some("FOO".to_string()),
                 input_match_saddr: false,
                 forward: None,
@@ -1231,9 +1258,9 @@ mod tests {
         .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x1234FEDC.into()).unwrap(),
+            resources.get(&0x1234_FEDC.into()).unwrap(),
             &Resource::Jump {
-                id: 0x1234FEDC.into(),
+                id: 0x1234_FEDC.into(),
                 input: Some("FOO".to_string()),
                 input_match_saddr: true,
                 forward: Some("BAR".to_string()),
@@ -1250,9 +1277,9 @@ mod tests {
             .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x1234FEDC.into()).unwrap(),
+            resources.get(&0x1234_FEDC.into()).unwrap(),
             &Resource::Jump {
-                id: 0x1234FEDC.into(),
+                id: 0x1234_FEDC.into(),
                 input: Some("FOO".to_string()),
                 input_match_saddr: false,
                 forward: Some("BAR".to_string()),
@@ -1271,9 +1298,9 @@ mod tests {
         .unwrap();
         let resources = get_resources(&ini).unwrap();
         assert_eq!(
-            resources.get(&0x1234FEDC.into()).unwrap(),
+            resources.get(&0x1234_FEDC.into()).unwrap(),
             &Resource::Jump {
-                id: 0x1234FEDC.into(),
+                id: 0x1234_FEDC.into(),
                 input: None,
                 input_match_saddr: false,
                 forward: Some("BAR".to_string()),
