@@ -67,8 +67,8 @@ pub fn parse_hex<const SIZE: usize>(s: &str) -> ah::Result<[u8; SIZE]> {
     }
     let mut ret = [0; SIZE];
     for i in 0..SIZE {
-        ret[i] = parse_hexdigit(&s[i * 2..i * 2 + 1])? << 4;
-        ret[i] |= parse_hexdigit(&s[i * 2 + 1..i * 2 + 2])?;
+        ret[i] = parse_hexdigit(&s[(i * 2)..=(i * 2)])? << 4;
+        ret[i] |= parse_hexdigit(&s[(i * 2 + 1)..=(i * 2 + 1)])?;
     }
     Ok(ret)
 }
@@ -77,10 +77,11 @@ pub fn parse_duration(s: &str) -> ah::Result<Duration> {
     if let Ok(secs) = parse_u32(s) {
         return Ok(Duration::from_secs(secs.into()));
     }
-    if let Ok(secs) = parse_f64(s) {
-        if secs >= 0.0 && secs <= u32::MAX.into() {
-            return Ok(Duration::from_secs_f64(secs));
-        }
+    if let Ok(secs) = parse_f64(s)
+        && secs >= 0.0
+        && secs <= u32::MAX.into()
+    {
+        return Ok(Duration::from_secs_f64(secs));
     }
     Err(err!("Invalid Duration"))
 }
