@@ -14,7 +14,7 @@
 
 #![forbid(unsafe_code)]
 
-use anyhow::{self as ah, format_err as err, Context as _};
+use anyhow::{self as ah, Context as _, format_err as err};
 use letmein_conf::ConfigChecksum;
 use letmein_proto::{ResourceId, UserId};
 use std::{
@@ -164,6 +164,7 @@ fn octets_to_addr(addr_type: AddrType, addr: &[u8; ADDR_SIZE]) -> IpAddr {
 
 impl FirewallMessage {
     /// Construct a new message to install firewall rules for a resource.
+    #[must_use]
     pub fn new_install(
         user: UserId,
         resource: ResourceId,
@@ -182,6 +183,7 @@ impl FirewallMessage {
     }
 
     /// Construct a new message to revoke firewall rule for a resource.
+    #[must_use]
     pub fn new_revoke(
         user: UserId,
         resource: ResourceId,
@@ -200,6 +202,7 @@ impl FirewallMessage {
     }
 
     /// Construct a new acknowledge message.
+    #[must_use]
     pub fn new_ack() -> Self {
         Self {
             operation: FirewallOperation::Ack,
@@ -208,6 +211,7 @@ impl FirewallMessage {
     }
 
     /// Construct a new not-acknowledge message.
+    #[must_use]
     pub fn new_nack() -> Self {
         Self {
             operation: FirewallOperation::Nack,
@@ -216,21 +220,25 @@ impl FirewallMessage {
     }
 
     /// Get the operation type from this message.
+    #[must_use]
     pub fn operation(&self) -> FirewallOperation {
         self.operation
     }
 
     /// Get the user ID from this message.
+    #[must_use]
     pub fn user(&self) -> UserId {
         self.user
     }
 
     /// Get the resource ID from this message.
+    #[must_use]
     pub fn resource(&self) -> ResourceId {
         self.resource
     }
 
     /// Get the `IpAddr` from this message.
+    #[must_use]
     pub fn addr(&self) -> Option<IpAddr> {
         match self.operation {
             FirewallOperation::Install | FirewallOperation::Revoke => {
@@ -241,6 +249,7 @@ impl FirewallMessage {
     }
 
     /// Get the configuration checksum from this message.
+    #[must_use]
     pub fn conf_checksum(&self) -> Option<&ConfigChecksum> {
         match self.operation {
             FirewallOperation::Install | FirewallOperation::Revoke => Some(&self.conf_cs),
@@ -276,6 +285,7 @@ impl FirewallMessage {
     }
 
     /// Try to deserialize a byte stream into a message.
+    #[allow(clippy::items_after_statements)]
     pub fn try_msg_deserialize(buf: &[u8]) -> ah::Result<Self> {
         if buf.len() != FWMSG_SIZE {
             return Err(err!("Deserialize: Raw message size mismatch."));
@@ -408,8 +418,8 @@ mod tests {
     #[test]
     fn test_msg_install_v6() {
         let msg = FirewallMessage::new_install(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "::1".parse().unwrap(),
             &ConfigChecksum::calculate(b"foo"),
         );
@@ -418,8 +428,8 @@ mod tests {
         check_ser_de(&msg);
 
         let msg = FirewallMessage::new_install(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "0102:0304:0506:0708:090A:0B0C:0D0E:0F10".parse().unwrap(),
             &ConfigChecksum::calculate(b"foo"),
         );
@@ -441,8 +451,8 @@ mod tests {
         );
 
         let msg = FirewallMessage::new_install(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "0102:0304:0506:0708:090A:0B0C:0D0E:0F10".parse().unwrap(),
             &ConfigChecksum::calculate(b"foo"),
         );
@@ -464,8 +474,8 @@ mod tests {
         );
 
         let msg = FirewallMessage::new_install(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "0102:0304:0506:0708:090A:0B0C:0D0E:0F10".parse().unwrap(),
             &ConfigChecksum::calculate(b"bar"),
         );
@@ -490,8 +500,8 @@ mod tests {
     #[test]
     fn test_msg_install_v4() {
         let msg = FirewallMessage::new_install(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "1.2.3.4".parse().unwrap(),
             &ConfigChecksum::calculate(b"foo"),
         );
@@ -520,8 +530,8 @@ mod tests {
     #[test]
     fn test_msg_revoke_v6() {
         let msg = FirewallMessage::new_revoke(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "0102:0304:0506:0708:090A:0B0C:0D0E:0F10".parse().unwrap(),
             &ConfigChecksum::calculate(b"foo"),
         );
@@ -553,8 +563,8 @@ mod tests {
     #[test]
     fn test_msg_revoke_v4() {
         let msg = FirewallMessage::new_revoke(
-            0x66773322.into(),
-            0xAABB9988.into(),
+            0x6677_3322.into(),
+            0xAABB_9988.into(),
             "1.2.3.4".parse().unwrap(),
             &ConfigChecksum::calculate(b"foo"),
         );
