@@ -7,27 +7,27 @@
 // SPDX-License-Identifier: Apache-2.0 OR MIT
 
 use crate::DEBUG;
-use anyhow::{self as ah, format_err as err, Context as _};
+use anyhow::{self as ah, Context as _, format_err as err};
 use std::{
     collections::{HashMap, VecDeque},
     io::ErrorKind,
     net::SocketAddr,
     sync::{
-        atomic::{self, AtomicBool},
         Arc, Mutex as StdMutex,
+        atomic::{self, AtomicBool},
     },
     time::Duration,
 };
 use tokio::{
     net::{TcpStream, UdpSocket},
     sync::{
-        watch::{channel, Receiver, Sender},
         Mutex,
+        watch::{Receiver, Sender, channel},
     },
     time::sleep,
 };
 
-/// One connection for use by [UdpDispatcherRx].
+/// One connection for use by [`UdpDispatcherRx`].
 #[derive(Debug)]
 struct UdpConn<const MSG_SIZE: usize, const Q_SIZE: usize> {
     /// The receive-queue for this connection.
@@ -66,7 +66,7 @@ struct UdpDispatcherRx<const MSG_SIZE: usize, const Q_SIZE: usize> {
 }
 
 impl<const MSG_SIZE: usize, const Q_SIZE: usize> UdpDispatcherRx<MSG_SIZE, Q_SIZE> {
-    /// Create a new [UdpDispatcherRx]
+    /// Create a new [`UdpDispatcherRx`]
     /// with the given maximum possible number of connections.
     fn new(max_nr_conn: usize) -> Self {
         UdpDispatcherRx {
@@ -104,7 +104,7 @@ impl<const MSG_SIZE: usize, const Q_SIZE: usize> UdpDispatcherRx<MSG_SIZE, Q_SIZ
                 assert!(conn.rx_queue.len() <= Q_SIZE);
                 if conn.rx_queue.len() == Q_SIZE {
                     self.conn.remove(&peer_addr); // Close connection.
-                    return Err(err!("UDP socket read: RX queue overflow (max={}).", Q_SIZE));
+                    return Err(err!("UDP socket read: RX queue overflow (max={Q_SIZE})."));
                 }
                 conn.rx_queue.push_back(buf);
                 let accepted = conn.accepted;
@@ -161,7 +161,7 @@ impl<const MSG_SIZE: usize, const Q_SIZE: usize> UdpDispatcherRx<MSG_SIZE, Q_SIZ
                 eprintln!("UDP-dispatcher: try_recv error during try_accept: {e:?}");
             }
             return None;
-        };
+        }
         for conn in &mut self.conn.values_mut() {
             if !conn.accepted {
                 conn.accepted = true;
@@ -224,7 +224,7 @@ pub struct UdpDispatcher<const MSG_SIZE: usize, const Q_SIZE: usize> {
 }
 
 impl<const MSG_SIZE: usize, const Q_SIZE: usize> UdpDispatcher<MSG_SIZE, Q_SIZE> {
-    /// Create a new [UdpDispatcher]
+    /// Create a new [`UdpDispatcher`]
     /// with the given UDP socket and
     /// with the given maximum possible number of connections.
     pub fn new(socket: UdpSocket, max_nr_conn: usize) -> Self {
@@ -319,6 +319,7 @@ impl<const MSG_SIZE: usize, const Q_SIZE: usize> UdpDispatcher<MSG_SIZE, Q_SIZE>
     }
 
     /// Disconnect the connection identified by the `peer_addr`.
+    #[allow(clippy::unused_async)]
     pub async fn disconnect(&self, peer_addr: SocketAddr) {
         self.rx
             .lock()
@@ -331,7 +332,7 @@ impl<const MSG_SIZE: usize, const Q_SIZE: usize> UdpDispatcher<MSG_SIZE, Q_SIZE>
 /// over a TCP connection.
 #[derive(Debug)]
 pub struct NetSocketTcp {
-    /// The [TcpStream] of this TCP connection.
+    /// The [`TcpStream`] of this TCP connection.
     stream: TcpStream,
 
     /// Closed-flag. Note that this does *not* mean that the `stream` is closed.
@@ -364,7 +365,7 @@ pub enum NetSocket<const MSG_SIZE: usize, const Q_SIZE: usize> {
 }
 
 impl<const MSG_SIZE: usize, const Q_SIZE: usize> NetSocket<MSG_SIZE, Q_SIZE> {
-    /// Create a new [NetSocket] from a [TcpStream] connection.
+    /// Create a new [`NetSocket`] from a [`TcpStream`] connection.
     pub fn from_tcp(stream: TcpStream) -> ah::Result<Self> {
         // Disable Nagle's algorithm.
         // We want to send our small packets as quickly as possible.
@@ -376,7 +377,7 @@ impl<const MSG_SIZE: usize, const Q_SIZE: usize> NetSocket<MSG_SIZE, Q_SIZE> {
         }))
     }
 
-    /// Create a new [NetSocket] from a [UdpDispatcher]
+    /// Create a new [`NetSocket`] from a [`UdpDispatcher`]
     /// and the specified connected `peer_addr`.
     pub fn from_udp(
         disp: Arc<UdpDispatcher<MSG_SIZE, Q_SIZE>>,
