@@ -7,12 +7,14 @@
 // SPDX-License-Identifier: Apache-2.0 OR MIT
 
 #![forbid(unsafe_code)]
+#![allow(clippy::cast_lossless)]
+#![allow(clippy::cast_possible_wrap)]
 
 #[cfg(not(any(target_os = "linux", target_os = "android")))]
 std::compile_error!("letmeind server and letmein-seccomp do not support non-Linux platforms.");
 
 use anyhow::{self as ah, Context as _};
-use seccompiler::{apply_filter_all_threads, BpfProgram};
+use seccompiler::{BpfProgram, apply_filter_all_threads};
 use std::env::consts::ARCH;
 
 #[cfg(has_seccomp_support)]
@@ -30,9 +32,12 @@ macro_rules! sys {
 }
 
 #[cfg(has_seccomp_support)]
-fn seccomp_cond(idx: u8, value: u64, bit_width: u8) -> ah::Result<seccompiler::SeccompCondition> {
+#[allow(clippy::cast_sign_loss)]
+fn seccomp_cond(idx: u8, value: i64, bit_width: u8) -> ah::Result<seccompiler::SeccompCondition> {
     use seccompiler::{SeccompCmpArgLen, SeccompCmpOp, SeccompCondition};
 
+    let value = value as u64;
+
     let bit_width = match bit_width {
         PTR => {
             #[cfg(target_pointer_width = "32")]
@@ -48,7 +53,11 @@ fn seccomp_cond(idx: u8, value: u64, bit_width: u8) -> ah::Result<seccompiler::S
 
     let arglen = match bit_width {
         32 => {
-            assert_eq!(value & 0xFFFF_FFFF_0000_0000, 0);
+            if value & 0x8000_0000 == 0 {
+                assert_eq!(value & 0xFFFF_FFFF_0000_0000, 0);
+            } else {
+                assert_eq!(value & 0xFFFF_FFFF_0000_0000, 0xFFFF_FFFF_0000_0000);
+            }
             SeccompCmpArgLen::Dword
         }
         64 => SeccompCmpArgLen::Qword,
@@ -72,6 +81,7 @@ macro_rules! args {
 }
 
 /// Returns `true` if seccomp is supported on this platform.
+#[must_use]
 pub fn seccomp_supported() -> bool {
     cfg!(any(has_seccomp_support))
 }
@@ -132,6 +142,8 @@ impl Filter {
     }
 
     #[cfg(has_seccomp_support)]
+    #[allow(clippy::too_many_lines)]
+    #[allow(clippy::items_after_statements)]
     pub fn compile_for_arch(allow: &[Allow], deny_action: Action, arch: &str) -> ah::Result<Self> {
         assert!(!allow.is_empty());
 
