@@ -6,8 +6,8 @@
 // or the MIT license, at your option.
 // SPDX-License-Identifier: Apache-2.0 OR MIT
 
-use crate::resolver::{resolve, ResConf};
-use anyhow::{self as ah, format_err as err, Context as _};
+use crate::resolver::{ResConf, resolve};
+use anyhow::{self as ah, Context as _, format_err as err};
 use letmein_conf::ControlPort;
 use letmein_proto::{Message, MsgNetSocket, MsgUdpDispatcher, Operation};
 use std::{
@@ -83,7 +83,7 @@ impl Client {
     /// Receive a specific message type from the TCP control connection.
     ///
     /// Returns an error, if another message type is received.
-    /// Returns an error, if a [Operation::GoAway] type Message is received.
+    /// Returns an error, if a [`Operation::GoAway`] type Message is received.
     pub async fn recv_specific_msg(&mut self, expect_operation: Operation) -> ah::Result<Message> {
         let reply = self.recv_msg().await.context("Receive knock reply")?;
         let Some(reply) = reply else {
