@@ -8,9 +8,9 @@
 
 use crate::{
     client::Client,
-    resolver::{is_ipv4_addr, is_ipv6_addr, ResConf, ResCrypt, ResMode, ResSrv},
+    resolver::{ResConf, ResCrypt, ResMode, ResSrv, is_ipv4_addr, is_ipv6_addr},
 };
-use anyhow::{self as ah, format_err as err, Context as _};
+use anyhow::{self as ah, Context as _, format_err as err};
 use letmein_conf::{Config, ControlPort};
 use letmein_proto::{Key, Message, Operation, ResourceId, UserId};
 use std::{path::Path, time::Duration};
@@ -52,6 +52,7 @@ struct KnockSeq<'a> {
 
 impl KnockSeq<'_> {
     /// Check if the server replied with a valid message.
+    #[allow(clippy::unnecessary_wraps)]
     fn check_reply(&self, msg: &Message) -> ah::Result<()> {
         if msg.user() != self.user {
             eprintln!(
@@ -182,7 +183,10 @@ async fn run_knock_or_revoke(
 
     let user = user.unwrap_or_else(|| conf.default_user());
     let Some(key) = conf.key(user) else {
-        return Err(err!("No key found in {confpath:?} for user {user}"));
+        return Err(err!(
+            "No key found in {} for user {user}",
+            confpath.display()
+        ));
     };
 
     let resource = match resource {
@@ -190,7 +194,8 @@ async fn run_knock_or_revoke(
         KnockResource::Port(port) => {
             let Some(resource) = conf.resource_id_by_port(port, Some(user)) else {
                 return Err(err!(
-                    "Port {port} is not mapped to a port-resource in {confpath:?}"
+                    "Port {port} is not mapped to a port-resource in {}",
+                    confpath.display()
                 ));
             };
             resource
