@@ -16,13 +16,13 @@ mod seccomp;
 use crate::{
     command::{
         genkey::run_genkey,
-        knock::{run_knock, run_revoke, KnockResource, KnockServer},
+        knock::{KnockResource, KnockServer, run_knock, run_revoke},
     },
     resolver::{ResCrypt, ResSrv},
     seccomp::install_seccomp_rules,
 };
-use anyhow::{self as ah, format_err as err, Context as _};
-use clap::{CommandFactory, Parser, Subcommand};
+use anyhow::{self as ah, Context as _, format_err as err};
+use clap::{CommandFactory as _, Parser, Subcommand};
 use letmein_conf::{Config, ConfigVariant, Seccomp};
 use letmein_proto::{ResourceId, UserId};
 use std::{path::PathBuf, sync::Arc, time::Duration};
