@@ -6,10 +6,10 @@
 // or the MIT license, at your option.
 // SPDX-License-Identifier: Apache-2.0 OR MIT
 
-use anyhow::{self as ah, format_err as err, Context as _};
+use anyhow::{self as ah, Context as _, format_err as err};
 use letmein_conf::Config;
 use letmein_proto::{Message, MsgNetSocket, MsgUdpDispatcher};
-use letmein_systemd::{systemd_notify_ready, SystemdSocket};
+use letmein_systemd::{SystemdSocket, systemd_notify_ready};
 use std::{
     convert::Infallible,
     net::{Ipv6Addr, SocketAddr},
@@ -25,7 +25,7 @@ use tokio::{
 
 async fn sleep_forever() -> Infallible {
     loop {
-        time::sleep(Duration::from_secs(31536000000)).await;
+        time::sleep(Duration::from_secs(31_536_000_000)).await;
     }
 }
 
@@ -44,12 +44,12 @@ pub struct Connection {
 }
 
 impl Connection {
-    fn new(socket: MsgNetSocket, peer_addr: SocketAddr, l4proto: &'static str) -> ah::Result<Self> {
-        Ok(Self {
+    fn new(socket: MsgNetSocket, peer_addr: SocketAddr, l4proto: &'static str) -> Self {
+        Self {
             socket,
             peer_addr,
             l4proto,
-        })
+        }
     }
 }
 
@@ -121,7 +121,7 @@ impl Server {
 
         // Get socket from systemd?
         if !no_systemd {
-            for socket in SystemdSocket::get_all()?.into_iter() {
+            for socket in SystemdSocket::get_all()? {
                 match socket {
                     SystemdSocket::Tcp(listener) => {
                         if tcp.is_some() {
@@ -212,13 +212,13 @@ impl Server {
                 self.tcp_join = spawn_tcp_accept(Arc::clone(&self.tcp));
                 let (stream, peer_addr) = result??;
                 let ns = MsgNetSocket::from_tcp(stream)?;
-                Ok(Connection::new(ns, peer_addr, "TCP")?)
+                Ok(Connection::new(ns, peer_addr, "TCP"))
             }
             result = &mut self.udp_join => {
                 self.udp_join = spawn_udp_accept(Arc::clone(&self.udp));
                 let (udp_disp, peer_addr) = result??;
                 let ns = MsgNetSocket::from_udp(udp_disp, peer_addr)?;
-                Ok(Connection::new(ns, peer_addr, "UDP")?)
+                Ok(Connection::new(ns, peer_addr, "UDP"))
             }
         }
     }
