@@ -10,12 +10,12 @@ use crate::firewall::{
     FirewallAction, FirewallChain, FirewallJumpTargets, FirewallMaintain, JumpLeaseMap, Lease,
     LeaseMapOps as _, LeasePort, LeaseType, PortLeaseMap, SingleLeasePort,
 };
-use anyhow::{self as ah, format_err as err, Context as _};
+use anyhow::{self as ah, Context as _, format_err as err};
 use letmein_conf::Config;
 use nftables::{
     batch::Batch,
     expr::{Expression, NamedExpression, Payload, PayloadField},
-    helper::{apply_ruleset_with_args_async, get_current_ruleset_with_args_async, DEFAULT_ARGS},
+    helper::{DEFAULT_ARGS, apply_ruleset_with_args_async, get_current_ruleset_with_args_async},
     schema::{Chain, FlushObject, NfCmd, NfListObject, NfObject, Rule},
     stmt::{Counter, JumpTarget, Match, Operator, Statement},
     types::NfFamily,
@@ -72,6 +72,7 @@ impl<'a> NftNames<'a> {
         })
     }
 
+    #[allow(clippy::unnecessary_wraps)]
     fn get_chain_input(&self) -> ah::Result<&'a str> {
         Ok(self.chain_input)
     }
@@ -106,11 +107,7 @@ impl<'a> NftNames<'a> {
 }
 
 fn option_if<T>(t: T, c: bool) -> Option<T> {
-    if c {
-        Some(t)
-    } else {
-        None
-    }
+    if c { Some(t) } else { None }
 }
 
 /// Create an nftables IP source address match statement.
@@ -315,6 +312,7 @@ fn gen_add_lease_cmds<'a>(
 }
 
 /// Generate the nftables flush-chain command to delete the contents of a chain.
+#[allow(clippy::unnecessary_wraps)]
 fn gen_flush_chain_cmd<'a>(names: &'a NftNames<'a>, chain: &'a str) -> ah::Result<NfCmd<'a>> {
     Ok(NfCmd::Flush(FlushObject::Chain(Chain {
         family: names.family,
@@ -482,6 +480,7 @@ impl NftFirewallInner {
     }
 
     /// Print the number of rules required for all leases.
+    #[allow(clippy::match_wildcard_for_single_variants)]
     fn print_total_rule_count(&self, conf: &Config) {
         if conf.debug() {
             let mut count: usize = self.num_ctrl_rules.into();
